<?php
/**
 * @copyright      Copyright (C) 2010 - 2012 MintJoomla. All rights reserved.
 * @license        GNU/GPL, see LICENSE.php
 *
 * EasySocial is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 */
defined('_JEXEC') or die('Unauthorized Access');

Foundry::import('admin:/includes/apps/apps');
JFactory::getLanguage()->load('plg_app_user_cobalt', JPATH_ROOT);

/**
 * Cobalt application for EasySocial.
 *
 * @since     1.0
 * @author    mintjoomla.com
 */
class SocialUserAppCobalt6 extends SocialAppItem
{
	public function exists()
	{
		$file = JPATH_ROOT . '/components/com_cobalt/api.php';

		if(!JFile::exists($file))
		{
			return FALSE;
		}

		require_once($file);

		return TRUE;
	}

	public function onPrepareStream(SocialStreamItem &$item, $includePrivacy = TRUE)
	{
		if($item->context != 'cobalt6')
		{
			return;
		}
		// Test if cobalt exists;
		if(!$this->exists())
		{
			return;
		}

		// Load app's css file.
		$this->getApp()->loadCss();

		$options = new JRegistry($item->params);
		$record  = JTable::getInstance('Record', 'CobaltTable');
		$record->load($options->get('record_id'));
		if(!$record->id)
		{
			return;
		}
		$type    = ItemsStore::getType($record->type_id);
		$section = ItemsStore::getSection($options->get('section_id'));

		$user = array_shift($item->actors);

		if(!$user)
		{
			return;
		}

		if($user->isBlock())
		{
			$user_text = $user->getName();
		}
		else
		{
			$user_text = '<a href="' . $user->getPermalink() . '" data-es-profile-tooltip="' . $user->id . '">' . $user->getName() . '</a>';
		}

		$msg = str_replace(
			array(
				'[TYPE]',
				'[TITLE]',
				'[RECORD]',
				'[SECTION]',
				'[USER]',
				'[AUTHOR]',
				'[BY]',
				'[RATE]'
			),
			array(
				$type->name,
				$record->title,
				JHtml::link(JRoute::_(Url::record($record, $type, $section)), $record->title),
				JHtml::link(JRoute::_(Url::records($section)), $section->name),
				$user_text,
				($record->user_id ? CCommunityHelper::getName($record->user_id, $section) : NULL),
				($record->user_id ? CCommunityHelper::getName($record->user_id, $section) : NULL),
				$options->get('new_vote')
			), JText::_('EVENT_' . strtoupper($item->verb) . '_PERS'));

		$fields     = json_decode($record->fields, TRUE);
		$field_vals = new JRegistry($fields);

		foreach($fields as $id => $value)
		{
			if(strpos($msg, "[{$id}]") !== FALSE)
			{
				if(is_array($value))
				{
					$value = implode(',', $value);
				}
				$msg = str_replace("[{$id}]", $value, $msg);
			}


			if(preg_match_all("/\[{$id}::(.*)\]/iU", $msg, $matches))
			{
				foreach($matches[0] AS $key => $match)
				{
					$path = $id . "." . str_replace('::', '.', $matches[1][$key]);
					if($field_vals->get($path))
					{
						$msg = str_replace($match, $field_vals->get($path), $msg);
					}
					$msg = str_replace($match, '', $msg);
				}
			}
		}

		$categories = json_decode($record->categories, TRUE);
		$msg = str_replace("[CAT]", implode(', ', $categories), $msg);

		$msg = preg_replace('/\[[^\]]*\]/iU', '', $msg);

		$item->display = $this->getParams()->get('stream_view', 'full');
		$item->title   = $msg;

		if($this->getParams()->get('stream_view', 'full') == 'full')
		{
			$model_record = JModelLegacy::getInstance('Record', 'CobaltModel');
			$record       = $model_record->_prepareItem($record);
			$this->set('record', $record);
			$this->set('section', $section);
			$this->set('type', $type);
			$this->set('options', $options);
			$this->set('user', $user);

			$file          = 'content/default';
			$contents      = parent::display($file);
			$item->content = $contents;
		}
	}

	public function appListing($view)
	{
		if($view == 'profile' && !$this->getParams()->get('enable_profile', 1))
		{
			return FALSE;
		}

		if($view == 'dashboard' && !$this->getParams()->get('enable_dashboard', 1))
		{
			return FALSE;
		}

		return TRUE;
	}
}
